bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift B ## 19. Aventiure
___________________________________________________
| ### <Do> div edel Criemhilt also verwitwet wart ### bi ir ime lande der grave Ecchewart ### beleip mit sinen mannen der dienet ir zallen tagen ### der half ovch siner vrowen sinen herren diche chlagen ### Ze Wormez bi dem mvnster ein gezimmber man ir sloz ### wit vnd vil michel rich vnd groz ### da si mit ir gesinde sit ane vrevde saz ### si was cer chirchen gerne vnd tet vil gvetlichen daz
###### 1100 | ### Da man begrvb ir vriedel wi selten si daz lie ### mit trvregem mvte si alle cit dar gie ### si bat got den gvten siner sele pflegen ### vil diche wart beweinet mit grozzen triwen der degen
| ### Vte vnd ir gesinde trosten si zaller stvnt ### do was ir daz herce so grozliche wnt ### ez chvnde niht vervahen swaz man ir trostes bot ### si hete nach liebem vrivnde di aller grosten not
###### 1102 | ### di nach liebem manne ie mer wip gewan ### man mohte ir michel tvgende chiesen wol dar an ### si chlagete vnz an ir ende di wile wert si der lip ### sit rach sich wol mit ellen des chvenen Sefrides wip
###### 1103 | ### Svs saz si nach ir leide daz ist alle war ### nach ir mannes tode wol vierdehalbez iar ### daz si ce Gvnther nie dehein wort gesprach ### vnt ovch ir vient Hagenen in der cite nie gesach
| ### Do sprach der helt von Tronege moht ir daz tragen an ### daz ir iwer swester ce vrivnde mohtet han ### so chome ce disen landen daz Nibelvnges golt ### des moht ir vil gewinnen werd vns div chvneginne holt
###### 1105 | ### Er sprach wir svln iz versvchen mine brvder sint ir bi [343a] ### di svl wirz piten werben daz si vnser vrivnt si ### ob virn ir an gewinnen daz si daz gerne sehe ### ine trwes niht sprach Hagene daz daz immer geschehe
###### 1106 | ### Do hiez er Ortwinen hince hove gan ### vnt den margraven Geren do daz was getan ### man braht ovch Gernoten vnd Giselher daz chint ### si versvchtenz vrivntliche an vrovn Criemhilde sint
| ### Do sprach von Bvrgonden der chvne Gernot ### vrowe ir chlaget ce lange den Sifrides tot ### iv wil der chvenich rihten daz er sin niht hat erslagen ### man horet ivch zallen citen so rehte grozlichen chlagen
###### 1108 | ### Si sprach des zihet in niemen in slvch div Hagenen hant ### wa man in verhowen solde do er daz an mir ervant ### wi moht ich des getrwen daz er im wære gehaz ### ich hete wol behvtet sprach div chvneginne daz
###### 1109 | ### daz ich niht vermeldet hete sinen lip ### so lieze ich nv min weinen ich vil armes wip ### holt wirt ich in nimmer di ez da hant getan ### do begonde vlehen Giselher der vil wætliche man
| ### Ich wil den chvenich grvezen do si im des veriach ### mit sinen besten vrivnden man in vor ir sach ### done torste Hagen fvr si niht gegan ### wol wesse er sine schvlde er het ir leide getan
###### 1111 | ### Do si verchiesen wolde vf Gvnthern den haz ### ob er si chvessen solde ez zæme im deste baz ### wære ir von sinem rate leide niht <getan> ### so moeht er vnzwifellichen zv Criemhilde gan [343b]
###### 1112 | ### Ezen wart nie svne mit so vil træhen me ### gefveget vnder vrivnden ir tet ir schade we ### si verchos vf si alle wan vf den einem man ### in het erslagen niemen ez hete Hagen getan
| ### Dar nach vil vnlange trvgen si daz an ### daz div vrowe Criemhilt den grozen hort gewan ### von Nibelvnge lande vnd fvrten an den Rin ### er was ir morgengabe er solt ir pilliche sin
###### 1114 | ### Darnach fvr Giselher vnd Gernot ### <ir> ahzech hvndert mannen Criemhilt do gebot ### daz sin <holen> solden da er verborgen lach ### da sin der degen Albrich mit sinen besten vrivnden pflach
###### 1115 | ### Do man di von dem Rine nach dem schatze chomen sach ### Albrich der vil chvene zv sinen vrivnden sprach ### wirn getverren ir des hordes vor gehaben niht ### sit sin ce morgengabe div edel kveneginne ihit
| ### Doch wrdez nimmer sprach Albrich getan ### niwan daz wir vebele da verlorn han ### mit samt Sifrit di gvten tarnhvt ### want di trvch alle cite der schoenen Criemhilde trvt
###### 1117 | ### Nv ist ez Sifride leider vbel chomen ### daz vns di tarnchappen hat der helt benomen ### vnt daz im mvse dienen allez dize lant ### do gie der chamerære da er di slvzzel vant
###### 1118 | ### Ez stvnden vor dem berge di Criemhilde man ### vnd ovch ein teil ir mage den shaz den hiez man dan ### tragen zv dem scheffe an div schiffelin ### den fvrt man vf den vnden vnz ze berge an den Rin
| ### Nv mveget ir von dem horde wnder horen sagen ### swaz zwelf chanzwagene meiste mohten tragen ### in vier tagen vnd nahten von dem berge dan ### ovch mvose ir ietslicher des tages dristvnt gan
###### 1120 | ### Ezen was niht anders wan steine vnd [344a] golt ### vnt ob man al di werlde het da von versolt ### sine wære niht minner einer marche wert ### iane hetes schvlde niht gar Hagen gegert
###### 1121 | ### Der wnhs der lach dar vnder von golde ein rvetelin ### der daz het erchvnnet der mohte meister sin ### wol in aller werld veber einn ietslichen man ### der Albriches mage chom vil mit Gernote dan
| ### Do si den hort behielten in Gvntheres lant ### vnd sihes div chveneginne aller erst vnderwant ### in chamer vnd in tvernen sin wart vil getragen ### man gehorte nie daz vnder von gvte mere gesagen
###### 1123 | ### Vnd wære sin tvsent stvnde noch alse vil gewesen ### vnd solt der herre Sifrit gesvnder sin gewesen ### bi im wære Criemhilt hendebloz bestan ### getriwer wibes chvenne ein helt ni mer gewan
###### 1124 | ### Do si den hort nv hete do brahtes in daz lant ### vil vnchvnder rechen ia gap der vrowen hant ### daz man so grozzer milte mere ni gesach ### si pflach vil gvter tvgende des man der chveneginne iach
| ### Den armen vnt den richen begonde si nv geben ### daz da reite Hagene ob si solde leben ### noch decheine wile daz si so manigen man ### in ir dienst gewnne daz ez in leide mvs ergan
###### 1126 | ### Do sprach der chvenech Gvnther ir ist lip vnd gvt ### zwiv sol ich daz wenden swaz si da mit getvt ### ia derwap ich daz vil chvme daz si mir wart so holt ### nv en rvchen war si teile ir silber vnd ir golt
###### 1127 | ### Hagen sprach ce dem chvnige ez solde ein frvmer man ### deheinem einem wibe niht des hordes lan ### si bringet ez mit gabe noch vf den tach ### daz vil wol <geriwen> di chvenen Bvrgonden mach
| ### Do sprach der kvnich Gvnther <ich> swor ir einen eit ### daz ich ir getæte nimmer [344b] mere leit ### vnd wil es fvrbaz hveten si ist div swester min ### do sprach aber Hagene lat mich den schvldigen sin
###### 1129 | ### Ir svmeliche eide waren vmbehvht ### do namen si der witwen daz creftige gvt ### Hagen si der slvzzel aller vnderwant ### daz zvrnde ir brvder Gernot do er daz rehte bevant
###### 1130 | ### Do sprach der herre Giselher Hagen hat getan ### vil leides miner swester ich <sold> iz vnderstan ### wære er niht min mag ez gienge im an den lip ### iteniwez weinen tet do Sifrides wip
| ### Do sprach der herre Gernot ê daz wir immer sin ### gemvet mit dem golde wir soldenz in den Rin ### allez heizen senchen daz wer wol <getan> ### si gie vil chlegeliche fver ir brvder Gvnthere stan
###### 1132 | ### Si sprach vil lieber brvder do solt gedenchen min ### beidiv libes vnd gvtes soltv min voget sin ### do sprach er zv der vrowen daz sol sin getan ### als wir nv chomen widere wir haben ritens wan
###### 1133 | ### Der kvenich vnd sine mage rvmten do daz lant ### di aller besten dar vnder di man inder vant ### niwan Hagen aleine der beleip da dvrch haz ### den er trvch Criemhilde vnt tet vlizechliche daz
###### 1134 | ### <ê> daz der chvenich riche wære wider chomen ### di wile hete Hagene den shaz vil genomen ### er schvtten da ce Lôche allen in den Rin ### er wand er sold in nizen des enchvnde niht gesin
###### 1135 | ### Di fversten chomen widere mit in vil manich man ### Criemhilt ir schaden grozzen chlagen began ### mit meiden vnt mit vrowen in was harte leit ### gerne wær ir Giselher aller triwen bereit
###### 1136 | ### Do sprachen si gemeine er hat vbele getan ### ern tweich der fvrsten zorne also lange dan ### vnz er gewan ir hvlde sie liezen in genesin ### done chvnde im Criemhilt nimmer viender <sin> gewesin [345a]
| ### E daz von Tronege Hagene den shaz also verbarch ### do heten siz gevestent mit eiden also starch ### daz er verholn wære vnz ir einer mohte leben ### sine chvnden ins selben noch niemen ander gegeben
###### 1138 | ### Mit itenween leiden beswæret was ir mvt ### vmb ir mannes ende vnt do si ir daz gvt ### also gar genamen done gestvnt ir chlage ### des libes nimmer mere vnz an ir ivngesten tage
###### 1139 | ### Nach Sifrides tode daz ist al war ### si wonte in manigem sere drivcehn iar ### daz si des recken todes vergezzen chvnde niht ### si was im getriwe des ir div meiste menige iht

<<< Übersicht <<< vorige Seite nächste Seite >>>